'''
Created on 9 sept. 2025

@author: Fabrice de Chaumont
'''

class MiceCraft(object):
    
    '''
    Launch the demos
    '''


    def __init__(self ):
    
        '''
        Constructor
        '''
        print("MiceCraft test started.")
        
        
    def showDemo(self):
        """
        start demo interface of MiceCraft
        """
        print("MiceCraft show demo.")
        